

/**
 * @version 1.31 2002-07-06
 * @author Cay Horstmann
 */

import java.awt.Color;
import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ActionMap;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.InputMap;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JPopupMenu;
import javax.swing.KeyStroke;


/**
 * Example to show actions. 
 */
public class Swing03_ActionsDemo  {

	private static final long serialVersionUID = 1L;
	
	public static final int DEFAULT_WIDTH = 300;
	public static final int DEFAULT_HEIGHT = 200;
	
	JFrame frame; 


	public Swing03_ActionsDemo() {
		frame = new JFrame("ActionTest");
		frame.setSize(DEFAULT_WIDTH, DEFAULT_HEIGHT);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		// Add panel to frame
		ActionPanel panel = new ActionPanel();
		Container contentPane = frame.getContentPane();
		contentPane.add(panel);

		// create menu
		JMenuBar menuBar = new JMenuBar(); 
		frame.setJMenuBar(menuBar); 
		JMenu bgMenu = new JMenu("Background"); 
		menuBar.add(bgMenu); 
		bgMenu.add(new JMenuItem(panel.yellowAction)); 
		bgMenu.add(new JMenuItem(panel.blueAction)); 
		bgMenu.add(new JMenuItem(panel.redAction));
		
		frame.setVisible(true);
	}



	public static void main(String[] args) {
		Swing03_ActionsDemo app = new Swing03_ActionsDemo();
	}
}

class ActionPanel extends JPanel {
	
	Action yellowAction, blueAction, redAction; 
	JPopupMenu popUp; 
	
	public ActionPanel() {
		
		// Define actions 
		yellowAction = new ColorAction("Gelb", new ImageIcon(
				"yellow-ball.gif"), Color.YELLOW);
		blueAction = new ColorAction("Blau", new ImageIcon(
				"blue-ball.gif"), Color.BLUE);
		redAction = new ColorAction("Rot",
				new ImageIcon("red-ball.gif"), Color.RED);

		// Add buttons 
		add(new JButton(yellowAction)); 
		add(new JButton(blueAction));
		add(new JButton(redAction));

		// Define input map 
		InputMap imap = getInputMap( 
				JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);

		imap.put(KeyStroke.getKeyStroke("ctrl G"), "panel.yellow");
		imap.put(KeyStroke.getKeyStroke("ctrl B"), "panel.blue");
		imap.put(KeyStroke.getKeyStroke("ctrl R"), "panel.red");

		// Map names to actions 
		ActionMap amap = getActionMap();
		amap.put("panel.yellow", yellowAction);
		amap.put("panel.blue", blueAction);
		amap.put("panel.red", redAction);
		
		// create popup menu  
		popUp = new JPopupMenu(); 
		popUp.add(yellowAction); 
		popUp.add(blueAction); 
		popUp.add(redAction); 
		this.addMouseListener(new MouseAdapter() {
			public void mousePressed(MouseEvent e) {
				if (e.getButton() == MouseEvent.BUTTON3) {
					popUp.show(e.getComponent(), e.getX()-10, e.getY()-10); 
				}
			}
		}); 
	}

	/** Inner member class for ColorActions 
	 */
	public class ColorAction extends AbstractAction {
		
		/**
		 * Creates a color actions.
		 * 
		 * @param name Name of the action 
		 * @param icon Icon of the action 
		 * @param c Background color 
		 */
		public ColorAction(String name, Icon icon, Color c) {
			putValue(Action.NAME, name);
			putValue(Action.SMALL_ICON, icon);
			putValue(Action.SHORT_DESCRIPTION,
					"ndern der Grundflchenfarbe in " + name.toLowerCase());
			putValue("color", c);
		}

		public void actionPerformed(ActionEvent event) {
			// Set color 
			Color c = (Color) getValue("color");
			setBackground(c);
			repaint();
		}
	}
}


